==> dde-cooperation_1.1.2.tar.xz: BUILD/translations/dfmplugin-deliver/cooperation-transfer_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="60"/>
        <source>File transfer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="62"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/menu/cooperationmenuscene.cpp" line="32"/>
        <source>File transfer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="55"/>
        <source>File transfer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="150"/>
        <source>File transfer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="164"/>
        <source>Everyone in the same LAN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="165"/>
        <source>Only those who are collaborating are allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="166"/>
        <source>Not allow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="170"/>
        <source>Allows the following users to send files to me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>File save location</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-cooperation_1.1.13.tar.xz: BUILD/translations/dfmplugin-deliver/cooperation-transfer_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="60"/>
        <source>File transfer settings</source>
        <translation>Ρυθμίσεις μεταφοράς αρχείων</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="62"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>Ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/menu/cooperationmenuscene.cpp" line="32"/>
        <source>File transfer</source>
        <translation>Μεταφορά αρχείων</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/cooperationplugin.cpp" line="55"/>
        <source>File transfer</source>
        <translation>Μεταφορά αρχείων</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="150"/>
        <source>File transfer settings</source>
        <translation>Ρυθμίσεις μεταφοράς αρχείων</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="164"/>
        <source>Everyone in the same LAN</source>
        <translation>Όλοι στην ίδια δίκτυο LAN</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="165"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Επιτρέπονται μόνον όσοι συνεργάζονται</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="166"/>
        <source>Not allow</source>
        <translation>Δεν επιτρέπεται</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="170"/>
        <source>Allows the following users to send files to me</source>
        <translation>Επιτρέπει τους ακόλουθους χρήστες να στέλνουν αρχεία σε μένα</translation>
    </message>
    <message>
        <location filename="../src/dde-file-manager/dfmplugin-cooperation/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>File save location</source>
        <translation>Τοποθεσία αποθήκευσης αρχείων</translation>
    </message>
</context>
</TS>
